<h3 align="center">
<img src="https://github.com/guap-ml/guap-docs/blob/main/guap.png?raw=true" alt="guap" width="300"></a>
</h3>
<h3 align="center">The ✨magical✨ ML evaluation metric everyone can agree on</h3>

<p align="center">
<strong>
  <a href="#why-should-i-use-guap">Why Guap?</a> •
  <a href="#quickstart-install">Quickstart</a> •
  <a href="https://guap-ml.github.io/guap-docs/">Docs</a> •
  <a href="https://guap-ml.github.io/guap-docs/blog">Blog</a> •
  <a href="#license">License</a>
</strong>
</p>

<p align="center">
    <a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="Made with love" src="https://img.shields.io/badge/Made%20With-Love-orange.svg">
    </a>
	<a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="py version" src="https://img.shields.io/badge/python-3.6_|_3.7_|_3.8-blue">
    </a>
	    </a>
	<a href="https://github.com/chetanraj/awesome-github-badges">
        <img alt="version" src="https://img.shields.io/badge/version-0.1.0-gree">
    </a>
</p>



## Why should I use guap?
Our mission with guap is to align all stakeholders with measurable business outcomes by including the three core teams — business, data science and IT — throughout the life cycle of the AI models.

- Make collaboration healthier and clearer between tech and non-tech people
- Make better decisions at every stage of the ML project lifecycle

Want to know more? Read [Why guap exist](https://guap-ml.github.io/guap-docs/blog/why-guap).

## Quickstart Install
🚧 Under construction, too

## Contributing
Pull requests are welcome. You want to contribute? let's talk [@guap_ml](https://twitter.com/guap_ml)!

## License
[Apache License 2.0](http://www.apache.org/licenses/)
